==> apache-cxf-3.6.5-src.zip: apache-cxf-3.6.5-src/rt/transports/jms/src/main/java/org/apache/cxf/transport/jms/util/JMSDestinationResolver.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.transport.jms.util;

import javax.jms.Destination;
import javax.jms.JMSException;
import javax.jms.Session;
import javax.naming.NamingException;

public class JMSDestinationResolver implements DestinationResolver {
    JndiHelper jndiTemplate;

    public Destination resolveDestinationName(Session session, String destinationName, boolean pubSubDomain)
        throws JMSException {
        if (jndiTemplate != null) {
            try {
                return jndiTemplate.lookup(destinationName, Destination.class);
            } catch (NamingException e) {
                throw new RuntimeException(e.getMessage(), e);
            }
        }
        if (pubSubDomain) {
            return session.createTopic(destinationName);
        }
        return session.createQueue(destinationName);
    }

    public void setJndiTemplate(JndiHelper jt) {
        this.jndiTemplate = jt;
    }

}

==> apache-cxf-4.1.1-src.zip: apache-cxf-4.1.1-src/rt/transports/jms/src/main/java/org/apache/cxf/transport/jms/util/JMSDestinationResolver.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.cxf.transport.jms.util;

import javax.naming.NamingException;

import jakarta.jms.Destination;
import jakarta.jms.JMSException;
import jakarta.jms.Session;

public class JMSDestinationResolver implements DestinationResolver {
    JndiHelper jndiTemplate;

    public Destination resolveDestinationName(Session session, String destinationName, boolean pubSubDomain)
        throws JMSException {
        if (jndiTemplate != null) {
            try {
                return jndiTemplate.lookup(destinationName, Destination.class);
            } catch (NamingException e) {
                throw new RuntimeException(e.getMessage(), e);
            }
        }
        if (pubSubDomain) {
            return session.createTopic(destinationName);
        }
        return session.createQueue(destinationName);
    }

    public void setJndiTemplate(JndiHelper jt) {
        this.jndiTemplate = jt;
    }

}
